@@ -1,4 +1,4 @@
-/* $Id: loadavg.h,v 1.24 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: loadavg.h,v 1.25 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -65,16 +65,6 @@ void glibtop_init_loadavg_s (glibtop *server);
 void glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_loadavg [];
-extern const unsigned glibtop_types_loadavg [];
-extern const char *glibtop_labels_loadavg [];
-extern const char *glibtop_descriptions_loadavg [];
-
-#endif
 
 G_END_DECLS
 
